@@ -236,7 +236,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
     ]),
     entries: ::phf::Slice::Static(&[
         (".udo", &["Csound"]),
-        (".cs", &["Smalltalk", "C#"]),
+        (".cs", &["C#", "Smalltalk"]),
         (".cfm", &["ColdFusion"]),
         (".cproject", &["XML"]),
         (".dockerfile", &["Dockerfile"]),
@@ -246,7 +246,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".jsonc", &["JSON with Comments"]),
         (".cr", &["Crystal"]),
         (".rq", &["SPARQL"]),
-        (".fcgi", &["Lua", "Ruby", "PHP", "Python", "Perl", "Shell"]),
+        (".fcgi", &["Lua", "Python", "Perl", "PHP", "Shell", "Ruby"]),
         (".ipf", &["IGOR Pro"]),
         (".gn", &["GN"]),
         (".vh", &["SystemVerilog"]),
@@ -259,7 +259,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".pot", &["Gettext Catalog"]),
         (".xproj", &["XML"]),
         (".rdoc", &["RDoc"]),
-        (".ecl", &["ECL", "ECLiPSe"]),
+        (".ecl", &["ECLiPSe", "ECL"]),
         (".yaml.sed", &["YAML"]),
         (".lbx", &["TeX"]),
         (".myt", &["Myghty"]),
@@ -290,7 +290,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".wiki", &["MediaWiki"]),
         (".ph", &["Perl"]),
         (".eclass", &["Gentoo Eclass"]),
-        (".es", &["Erlang", "JavaScript"]),
+        (".es", &["JavaScript", "Erlang"]),
         (".xpl", &["XProc"]),
         (".fp", &["GLSL"]),
         (".yacc", &["Yacc"]),
@@ -301,7 +301,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".txl", &["TXL"]),
         (".tla", &["TLA"]),
         (".pod", &["Pod", "Pod 6"]),
-        (".cp", &["Component Pascal", "C++"]),
+        (".cp", &["C++", "Component Pascal"]),
         (".irclog", &["IRC log"]),
         (".as", &["AngelScript", "ActionScript"]),
         (".zimpl", &["Zimpl"]),
@@ -312,7 +312,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".clj", &["Clojure"]),
         (".pasm", &["Parrot Assembly"]),
         (".parrot", &["Parrot"]),
-        (".2", &["Roff Manpage", "Roff"]),
+        (".2", &["Roff", "Roff Manpage"]),
         (".cljc", &["Clojure"]),
         (".json5", &["JSON5"]),
         (".txt", &["Text"]),
@@ -322,13 +322,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vcl", &["VCL"]),
         (".las", &["Lasso"]),
         (".oz", &["Oz"]),
-        (".for", &["Forth", "Formatted", "Fortran"]),
+        (".for", &["Formatted", "Fortran", "Forth"]),
         (".php5", &["PHP"]),
         (".jake", &["JavaScript"]),
         (".c++", &["C++"]),
         (".meta", &["Unity3D Asset"]),
         (".gitignore", &["Ignore List"]),
-        (".6", &["Roff Manpage", "Roff"]),
+        (".6", &["Roff", "Roff Manpage"]),
         (".pub", &["Public Key"]),
         (".gsp", &["Groovy Server Pages"]),
         (".jsonnet", &["Jsonnet"]),
@@ -342,7 +342,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".asn", &["ASN.1"]),
         (".sublime-keymap", &["JSON with Comments"]),
         (".thy", &["Isabelle"]),
-        (".properties", &["INI", "Java Properties"]),
+        (".properties", &["Java Properties", "INI"]),
         (".xacro", &["XML"]),
         (".wlua", &["Lua"]),
         (".launch", &["XML"]),
@@ -360,7 +360,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".unity", &["Unity3D Asset"]),
         (".mediawiki", &["MediaWiki"]),
         (".j", &["Objective-J", "Jasmin"]),
-        (".gd", &["GDScript", "GAP"]),
+        (".gd", &["GAP", "GDScript"]),
         (".rbxs", &["Lua"]),
         (".erb.deface", &["HTML+ERB"]),
         (".regexp", &["Regular Expression"]),
@@ -379,7 +379,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bdy", &["PLSQL"]),
         (".nlogo", &["NetLogo"]),
         (".st", &["Smalltalk", "HTML"]),
-        (".1in", &["Roff Manpage", "Roff"]),
+        (".1in", &["Roff", "Roff Manpage"]),
         (".cfg", &["HAProxy", "INI"]),
         (".conll", &["CoNLL-U"]),
         (".bmx", &["BlitzMax"]),
@@ -395,7 +395,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".js.erb", &["JavaScript+ERB"]),
         (".fea", &["OpenType Feature File"]),
         (".zs", &["ZenScript"]),
-        (".4", &["Roff Manpage", "Roff"]),
+        (".4", &["Roff", "Roff Manpage"]),
         (".csh", &["Tcsh"]),
         (".nu", &["Nu"]),
         (".db2", &["SQLPL"]),
@@ -406,12 +406,12 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".kojo", &["Scala"]),
         (".cxx-objdump", &["Cpp-ObjDump"]),
         (".xc", &["XC"]),
-        (".spec", &["Ruby", "Python", "RPM Spec"]),
+        (".spec", &["Python", "RPM Spec", "Ruby"]),
         (".gmx", &["XML"]),
         (".self", &["Self"]),
         (".slim", &["Slim"]),
         (".apl", &["APL"]),
-        (".hh", &["Hack", "C++"]),
+        (".hh", &["C++", "Hack"]),
         (".gtpl", &["Groovy"]),
         (".lsl", &["LSL"]),
         (".blade", &["Blade"]),
@@ -423,30 +423,30 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sublime-snippet", &["XML"]),
         (".fsi", &["F#"]),
         (".tfvars", &["HCL"]),
-        (".1m", &["Roff Manpage", "Roff"]),
+        (".1m", &["Roff", "Roff Manpage"]),
         (".csv", &["CSV"]),
-        (".gs", &["Genie", "GLSL", "Gosu", "JavaScript"]),
-        (".vba", &["VBA", "Vim script"]),
+        (".gs", &["JavaScript", "Genie", "GLSL", "Gosu"]),
+        (".vba", &["Vim script", "VBA"]),
         (".escript", &["Erlang"]),
         (".owl", &["Web Ontology Language"]),
         (".plt", &["Gnuplot"]),
         (".c-objdump", &["C-ObjDump"]),
         (".vsixmanifest", &["XML"]),
         (".xib", &["XML"]),
-        (".brd", &["Eagle", "KiCad Legacy Layout"]),
+        (".brd", &["KiCad Legacy Layout", "Eagle"]),
         (".ll", &["LLVM"]),
         (".8xp", &["TI Program"]),
         (".fx", &["HLSL", "FLUX"]),
-        (".3", &["Roff Manpage", "Roff"]),
+        (".3", &["Roff", "Roff Manpage"]),
         (".tmpreferences", &["XML Property List"]),
         (".minid", &["MiniD"]),
         (".jinja", &["HTML+Django"]),
         (".xojo_script", &["Xojo"]),
         (".fxh", &["HLSL"]),
         (".gypi", &["Python"]),
-        (".pm", &["Perl", "Raku", "X PixMap"]),
+        (".pm", &["X PixMap", "Perl", "Raku"]),
         (".ml4", &["OCaml"]),
-        (".cake", &["CoffeeScript", "C#"]),
+        (".cake", &["C#", "CoffeeScript"]),
         (".pod6", &["Pod 6"]),
         (".rd", &["R"]),
         (".4dm", &["4D"]),
@@ -467,7 +467,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".nasl", &["NASL"]),
         (".latte", &["Latte"]),
         (".metal", &["Metal"]),
-        (".frag", &["GLSL", "JavaScript"]),
+        (".frag", &["JavaScript", "GLSL"]),
         (".ch", &["Charity", "xBase"]),
         (".cjs", &["JavaScript"]),
         (".glade", &["XML"]),
@@ -476,11 +476,11 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".fth", &["Forth"]),
         (".raw", &["Raw token data"]),
         (".tea", &["Tea"]),
-        (".man", &["Roff Manpage", "Roff"]),
+        (".man", &["Roff", "Roff Manpage"]),
         (".grt", &["Groovy"]),
         (".tmac", &["Roff"]),
         (".pyw", &["Python"]),
-        (".1x", &["Roff Manpage", "Roff"]),
+        (".1x", &["Roff", "Roff Manpage"]),
         (".ditaval", &["XML"]),
         (".pbt", &["PowerBuilder"]),
         (".sjs", &["JavaScript"]),
@@ -515,7 +515,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".go", &["Go"]),
         (".cpp-objdump", &["Cpp-ObjDump"]),
         (".xht", &["HTML"]),
-        (".re", &["Reason", "C++"]),
+        (".re", &["C++", "Reason"]),
         (".riot", &["Riot"]),
         (".zeek", &["Zeek"]),
         (".props", &["XML"]),
@@ -530,7 +530,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".liquid", &["Liquid"]),
         (".hb", &["Harbour"]),
         (".aw", &["PHP"]),
-        (".shader", &["ShaderLab", "GLSL"]),
+        (".shader", &["GLSL", "ShaderLab"]),
         (".decls", &["BlitzBasic"]),
         (".dtx", &["TeX"]),
         (".cps", &["Component Pascal"]),
@@ -540,7 +540,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sublime-settings", &["JSON with Comments"]),
         (".lpr", &["Pascal"]),
         (".pl6", &["Raku"]),
-        (".3qt", &["Roff Manpage", "Roff"]),
+        (".3qt", &["Roff", "Roff Manpage"]),
         (".robot", &["RobotFramework"]),
         (".yaml", &["YAML"]),
         (".nawk", &["Awk"]),
@@ -590,7 +590,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".hql", &["HiveQL"]),
         (".cppobjdump", &["Cpp-ObjDump"]),
         (".monkey2", &["Monkey"]),
-        (".7", &["Roff Manpage", "Roff"]),
+        (".7", &["Roff", "Roff Manpage"]),
         (".xtend", &["Xtend"]),
         (".tcl", &["Tcl"]),
         (".ssjs", &["JavaScript"]),
@@ -602,7 +602,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".pan", &["Pan"]),
         (".oxh", &["Ox"]),
         (".me", &["Roff"]),
-        (".s", &["Motorola 68K Assembly", "Unix Assembly"]),
+        (".s", &["Unix Assembly", "Motorola 68K Assembly"]),
         (".tst", &["Scilab", "GAP"]),
         (".gbo", &["Gerber Image"]),
         (".rviz", &["YAML"]),
@@ -610,7 +610,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".bbx", &["TeX"]),
         (".ijs", &["J"]),
         (".jisonlex", &["Jison Lex"]),
-        (".l", &["Common Lisp", "Lex", "PicoLisp", "Roff"]),
+        (".l", &["Roff", "Lex", "PicoLisp", "Common Lisp"]),
         (".rbbas", &["REALbasic"]),
         (".pkgproj", &["XML"]),
         (".scss", &["SCSS"]),
@@ -619,9 +619,9 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".plantuml", &["PlantUML"]),
         (".mcfunction", &["mcfunction"]),
         (".vhi", &["VHDL"]),
-        (".1", &["Roff Manpage", "Roff"]),
+        (".1", &["Roff", "Roff Manpage"]),
         (".befunge", &["Befunge"]),
-        (".fr", &["Forth", "Text", "Frege"]),
+        (".fr", &["Text", "Forth", "Frege"]),
         (".ccproj", &["XML"]),
         (".zone", &["DNS Zone"]),
         (".jsb", &["JavaScript"]),
@@ -640,14 +640,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".hqf", &["SQF"]),
         (".ne", &["Nearley"]),
         (".sublime_metrics", &["JSON with Comments"]),
-        (".5", &["Roff Manpage", "Roff"]),
+        (".5", &["Roff", "Roff Manpage"]),
         (".pic", &["Pic"]),
         (".pony", &["Pony"]),
         (".bones", &["JavaScript"]),
         (".ct", &["XML"]),
         (".pls", &["PLSQL"]),
         (".sass", &["Sass"]),
-        (".9", &["Roff Manpage", "Roff"]),
+        (".9", &["Roff", "Roff Manpage"]),
         (".csx", &["C#"]),
         (".zmpl", &["Zimpl"]),
         (".rdf", &["XML"]),
@@ -690,13 +690,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".xspec", &["XML"]),
         (".sublime-macro", &["JSON with Comments"]),
         (".ins", &["TeX"]),
-        (".moo", &["Moocode", "Mercury"]),
+        (".moo", &["Mercury", "Moocode"]),
         (".tfstate", &["JSON"]),
         (".mdown", &["Markdown"]),
         (".gst", &["Gosu"]),
         (".jsm", &["JavaScript"]),
         (".angelscript", &["AngelScript"]),
-        (".cls", &["TeX", "VBA", "Apex", "OpenEdge ABL", "ObjectScript"]),
+        (".cls", &["OpenEdge ABL", "TeX", "Apex", "ObjectScript", "VBA"]),
         (".workbook", &["Markdown"]),
         (".csproj", &["XML"]),
         (".tcsh", &["Tcsh"]),
@@ -715,7 +715,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vhf", &["VHDL"]),
         (".nuspec", &["XML"]),
         (".rst", &["reStructuredText"]),
-        (".m4", &["M4Sugar", "M4"]),
+        (".m4", &["M4", "M4Sugar"]),
         (".mkdown", &["Markdown"]),
         (".mo", &["Modelica"]),
         (".nr", &["Roff"]),
@@ -787,7 +787,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".frm", &["VBA"]),
         (".vark", &["Gosu"]),
         (".resx", &["XML"]),
-        (".md", &["GCC Machine Description", "Markdown"]),
+        (".md", &["Markdown", "GCC Machine Description"]),
         (".arc", &["Arc"]),
         (".roff", &["Roff"]),
         (".rebol", &["Rebol"]),
@@ -820,9 +820,9 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".rs.in", &["Rust"]),
         (".puml", &["PlantUML"]),
         (".mq4", &["MQL4"]),
-        (".php", &["PHP", "Hack"]),
+        (".php", &["Hack", "PHP"]),
         (".ahkl", &["AutoHotkey"]),
-        (".ms", &["MAXScript", "Unix Assembly", "Roff"]),
+        (".ms", &["Unix Assembly", "Roff", "MAXScript"]),
         (".epsi", &["PostScript"]),
         (".htm", &["HTML"]),
         (".nsh", &["NSIS"]),
@@ -857,7 +857,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".diff", &["Diff"]),
         (".nasm", &["Assembly"]),
         (".app.src", &["Erlang"]),
-        (".srt", &["SubRip Text", "SRecode Template"]),
+        (".srt", &["SRecode Template", "SubRip Text"]),
         (".nims", &["Nim"]),
         (".bzl", &["Starlark"]),
         (".ejs", &["EJS"]),
@@ -876,7 +876,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tex", &["TeX"]),
         (".erl", &["Erlang"]),
         (".glf", &["Glyph"]),
-        (".pro", &["Prolog", "IDL", "INI", "Proguard", "QMake"]),
+        (".pro", &["QMake", "IDL", "Prolog", "INI", "Proguard"]),
         (".mk", &["Makefile"]),
         (".mli", &["OCaml"]),
         (".cobol", &["COBOL"]),
@@ -888,14 +888,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".sed", &["sed"]),
         (".desktop", &["desktop"]),
         (".html.hl", &["HTML"]),
-        (".rs", &["RenderScript", "Rust"]),
+        (".rs", &["Rust", "RenderScript"]),
         (".scm", &["Scheme"]),
         (".pcbdoc", &["Altium Designer"]),
         (".spc", &["PLSQL"]),
         (".eex", &["HTML+EEX"]),
         (".php4", &["PHP"]),
         (".spin", &["Propeller Spin"]),
-        (".f", &["Forth", "Fortran", "Filebench WML"]),
+        (".f", &["Fortran", "Forth", "Filebench WML"]),
         (".cnc", &["G-code"]),
         (".mcmeta", &["JSON"]),
         (".smt", &["SMT"]),
@@ -911,7 +911,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".rg", &["Rouge"]),
         (".filters", &["XML"]),
         (".cpy", &["COBOL"]),
-        (".lisp", &["Common Lisp", "NewLisp"]),
+        (".lisp", &["NewLisp", "Common Lisp"]),
         (".rake", &["Ruby"]),
         (".pyde", &["Python"]),
         (".dfm", &["Pascal"]),
@@ -921,7 +921,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".js", &["JavaScript"]),
         (".hxsl", &["Haxe"]),
         (".no", &["Text"]),
-        (".ncl", &["NCL", "XML", "Text"]),
+        (".ncl", &["Text", "XML", "NCL"]),
         (".hack", &["Hack"]),
         (".lua", &["Lua"]),
         (".reg", &["Windows Registry Entries"]),
@@ -929,13 +929,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".i7x", &["Inform 7"]),
         (".dcl", &["Clean"]),
         (".applescript", &["AppleScript"]),
-        (".d", &["Makefile", "DTrace", "D"]),
+        (".d", &["D", "Makefile", "DTrace"]),
         (".admx", &["XML"]),
         (".webapp", &["JSON"]),
         (".em", &["EmberScript"]),
         (".gco", &["G-code"]),
         (".jsproj", &["XML"]),
-        (".3in", &["Roff Manpage", "Roff"]),
+        (".3in", &["Roff", "Roff Manpage"]),
         (".psgi", &["Perl"]),
         (".yml", &["YAML"]),
         (".jl", &["Julia"]),
@@ -963,7 +963,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".mdwn", &["Markdown"]),
         (".kicad_wks", &["KiCad Layout"]),
         (".jelly", &["XML"]),
-        (".prc", &["PLSQL", "SQL"]),
+        (".prc", &["SQL", "PLSQL"]),
         (".pde", &["Processing"]),
         (".vhd", &["VHDL"]),
         (".pgsql", &["PLpgSQL"]),
@@ -992,7 +992,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".asset", &["Unity3D Asset"]),
         (".hs-boot", &["Haskell"]),
         (".gpb", &["Gerber Image"]),
-        (".mod", &["AMPL", "Modula-2", "XML", "Linux Kernel Module"]),
+        (".mod", &["Linux Kernel Module", "XML", "AMPL", "Modula-2"]),
         (".mao", &["Mako"]),
         (".rex", &["REXX"]),
         (".jsp", &["Java Server Pages"]),
@@ -1006,7 +1006,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".ccxml", &["XML"]),
         (".plsql", &["PLSQL"]),
         (".geo", &["GLSL"]),
-        (".h", &["Objective-C", "C", "C++"]),
+        (".h", &["C", "C++", "Objective-C"]),
         (".gvy", &["Groovy"]),
         (".proj", &["XML"]),
         (".ceylon", &["Ceylon"]),
@@ -1028,7 +1028,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".agda", &["Agda"]),
         (".f08", &["Fortran"]),
         (".rktl", &["Racket"]),
-        (".3pm", &["Roff Manpage", "Roff"]),
+        (".3pm", &["Roff", "Roff Manpage"]),
         (".cl2", &["Clojure"]),
         (".shen", &["Shen"]),
         (".har", &["JSON"]),
@@ -1047,7 +1047,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".snip", &["Vim Snippet"]),
         (".f77", &["Fortran"]),
         (".sthlp", &["Stata"]),
-        (".fs", &["Forth", "Filterscript", "GLSL", "F#"]),
+        (".fs", &["Forth", "F#", "GLSL", "Filterscript"]),
         (".dm", &["DM"]),
         (".rb", &["Ruby"]),
         (".duby", &["Mirah"]),
@@ -1078,8 +1078,8 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".podspec", &["Ruby"]),
         (".4th", &["Forth"]),
         (".hx", &["Haxe"]),
-        (".8", &["Roff Manpage", "Roff"]),
-        (".sls", &["SaltStack", "Scheme"]),
+        (".8", &["Roff", "Roff Manpage"]),
+        (".sls", &["Scheme", "SaltStack"]),
         (".sh.in", &["Shell"]),
         (".watchr", &["Ruby"]),
         (".edn", &["edn"]),
@@ -1091,13 +1091,13 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".vshader", &["GLSL"]),
         (".dylan", &["Dylan"]),
         (".lasso", &["Lasso"]),
-        (".3m", &["Roff Manpage", "Roff"]),
+        (".3m", &["Roff", "Roff Manpage"]),
         (".nse", &["Lua"]),
         (".fancypack", &["Fancy"]),
         (".kml", &["XML"]),
         (".pytb", &["Python traceback"]),
         (".ihlp", &["Stata"]),
-        (".3x", &["Roff Manpage", "Roff"]),
+        (".3x", &["Roff", "Roff Manpage"]),
         (".dotsettings", &["XML"]),
         (".xslt", &["XSLT"]),
         (".cuh", &["Cuda"]),
@@ -1122,21 +1122,21 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".cljs", &["Clojure"]),
         (".mbox", &["EML"]),
         (".purs", &["PureScript"]),
-        (".ddl", &["PLSQL", "SQL"]),
+        (".ddl", &["SQL", "PLSQL"]),
         (".nut", &["Squirrel"]),
         (".csl", &["XML"]),
         (".less", &["Less"]),
         (".graphqls", &["GraphQL"]),
         (".sqf", &["SQF"]),
         (".v", &["Coq", "Verilog", "V"]),
-        (".mask", &["Unity3D Asset", "Mask"]),
+        (".mask", &["Mask", "Unity3D Asset"]),
         (".rexx", &["REXX"]),
         (".apacheconf", &["ApacheConf"]),
         (".kit", &["Kit"]),
         (".blade.php", &["Blade"]),
         (".doh", &["Stata"]),
         (".ps", &["PostScript"]),
-        (".sql", &["PLSQL", "TSQL", "PLpgSQL", "SQLPL", "SQL"]),
+        (".sql", &["SQLPL", "PLpgSQL", "SQL", "PLSQL", "TSQL"]),
         (".txi", &["Texinfo"]),
         (".sma", &["Pawn"]),
         (".wisp", &["wisp"]),
@@ -1155,17 +1155,17 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".capnp", &["Cap\'n Proto"]),
         (".tml", &["XML"]),
         (".forth", &["Forth"]),
-        (".lsp", &["Common Lisp", "NewLisp"]),
+        (".lsp", &["NewLisp", "Common Lisp"]),
         (".boo", &["Boo"]),
         (".sco", &["Csound Score"]),
-        (".inc", &["PHP", "Motorola 68K Assembly", "SourcePawn", "Assembly", "POV-Ray SDL", "Pawn", "NASL", "SQL", "C++", "HTML", "Pascal"]),
+        (".inc", &["POV-Ray SDL", "Pascal", "NASL", "SQL", "C++", "HTML", "Motorola 68K Assembly", "PHP", "SourcePawn", "Pawn", "Assembly"]),
         (".volt", &["Volt"]),
         (".yrl", &["Erlang"]),
-        (".asc", &["Public Key", "AsciiDoc", "AGS Script"]),
+        (".asc", &["AGS Script", "AsciiDoc", "Public Key"]),
         (".targets", &["XML"]),
         (".vw", &["PLSQL"]),
         (".geom", &["GLSL"]),
-        (".m", &["M", "Mathematica", "Objective-C", "MATLAB", "Mercury", "Limbo", "MUF"]),
+        (".m", &["MATLAB", "Mercury", "M", "Limbo", "Mathematica", "Objective-C", "MUF"]),
         (".yaml-tmlanguage", &["YAML"]),
         (".ahk", &["AutoHotkey"]),
         (".lslp", &["LSL"]),
@@ -1177,7 +1177,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".tab", &["SQL"]),
         (".y", &["Yacc"]),
         (".opal", &["Opal"]),
-        (".gml", &["Graph Modeling Language", "XML", "Gerber Image", "Game Maker Language"]),
+        (".gml", &["Graph Modeling Language", "XML", "Game Maker Language", "Gerber Image"]),
         (".njk", &["HTML+Django"]),
         (".yar", &["YARA"]),
         (".6pl", &["Raku"]),
@@ -1205,7 +1205,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".nc", &["nesC"]),
         (".pac", &["JavaScript"]),
         (".desktop.in", &["desktop"]),
-        (".pluginspec", &["Ruby", "XML"]),
+        (".pluginspec", &["XML", "Ruby"]),
         (".dae", &["COLLADA"]),
         (".vsh", &["GLSL"]),
         (".phps", &["PHP"]),
@@ -1224,7 +1224,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".zpl", &["Zimpl"]),
         (".ash", &["AGS Script"]),
         (".iml", &["XML"]),
-        (".mdoc", &["Roff Manpage", "Roff"]),
+        (".mdoc", &["Roff", "Roff Manpage"]),
         (".swift", &["Swift"]),
         (".pat", &["Max"]),
         (".mg", &["Modula-3"]),
@@ -1232,10 +1232,10 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".gshader", &["GLSL"]),
         (".phpt", &["PHP"]),
         (".brs", &["Brightscript"]),
-        (".bb", &["BlitzBasic", "BitBake"]),
+        (".bb", &["BitBake", "BlitzBasic"]),
         (".nix", &["Nix"]),
         (".sublime-workspace", &["JSON with Comments"]),
-        (".3p", &["Roff Manpage", "Roff"]),
+        (".3p", &["Roff", "Roff Manpage"]),
         (".ads", &["Ada"]),
         (".golo", &["Golo"]),
         (".cql", &["SQL"]),
@@ -1250,11 +1250,11 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".axs.erb", &["NetLinx+ERB"]),
         (".sublime_session", &["JSON with Comments"]),
         (".gdbinit", &["GDB"]),
-        (".p", &["Gnuplot", "OpenEdge ABL"]),
+        (".p", &["OpenEdge ABL", "Gnuplot"]),
         (".chem", &["Pic"]),
         (".mll", &["OCaml"]),
-        (".q", &["q", "HiveQL"]),
-        (".x", &["DirectX 3D File", "RPC", "Logos", "Linker Script"]),
+        (".q", &["HiveQL", "q"]),
+        (".x", &["Logos", "DirectX 3D File", "Linker Script", "RPC"]),
         (".cshtml", &["HTML+Razor"]),
         (".pt", &["XML"]),
         (".dats", &["ATS"]),
@@ -1269,10 +1269,10 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".xojo_window", &["Xojo"]),
         (".graphql", &["GraphQL"]),
         (".x3d", &["XML"]),
-        (".rpy", &["Python", "Ren\'Py"]),
+        (".rpy", &["Ren\'Py", "Python"]),
         (".r3", &["Rebol"]),
         (".jq", &["JSONiq"]),
-        (".tsx", &["XML", "TSX"]),
+        (".tsx", &["TSX", "XML"]),
         (".vstemplate", &["XML"]),
         (".plx", &["Perl"]),
         (".zcml", &["XML"]),
@@ -1291,14 +1291,14 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".haml", &["Haml"]),
         (".ly", &["LilyPond"]),
         (".abnf", &["ABNF"]),
-        (".ls", &["LiveScript", "LoomScript"]),
+        (".ls", &["LoomScript", "LiveScript"]),
         (".snippets", &["Vim Snippet"]),
         (".sbt", &["Scala"]),
         (".h++", &["C++"]),
         (".krl", &["KRL"]),
         (".litcoffee", &["Literate CoffeeScript"]),
         (".exs", &["Elixir"]),
-        (".vhost", &["Nginx", "ApacheConf"]),
+        (".vhost", &["ApacheConf", "Nginx"]),
         (".adoc", &["AsciiDoc"]),
         (".tmlanguage", &["XML Property List"]),
         (".xsp.metadata", &["XPages"]),
@@ -1323,7 +1323,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".csd", &["Csound Document"]),
         (".reek", &["YAML"]),
         (".dpatch", &["Darcs Patch"]),
-        (".nb", &["Mathematica", "Text"]),
+        (".nb", &["Text", "Mathematica"]),
         (".pxi", &["Cython"]),
         (".patch", &["Diff"]),
         (".urs", &["UrWeb"]),
@@ -1379,7 +1379,7 @@ static EXTENSIONS: phf::Map<&'static str, &[&str]> =
         (".eq", &["EQ"]),
         (".smali", &["Smali"]),
         (".vht", &["VHDL"]),
-        (".sch", &["Eagle", "XML", "Scheme", "KiCad Schematic"]),
+        (".sch", &["Scheme", "KiCad Schematic", "XML", "Eagle"]),
         (".sh", &["Shell"]),
         (".kt", &["Kotlin"]),
         (".prisma", &["Prisma"]),
